set more 1
capture log close

/*
File:	analyze_imf_lmi_5.do
Date:	Mar 22, 2004
Desc:	Analyzes data used for IMF, World Economic Outlook, April 2003,
	Chapter IV: Unemployment and Labor Market Institutions:
	Why Reforms Pay Off; includes material related to IMF response
*/

/* set directories
see master_imf_lmi.do
*/

set matsize 200

use "$mydoc$data\imf_lmi_ready.dta", clear

tsset cntry year, yearly
iis cntry
tis year

/*

log using "$mydoc$out\imf_lmi_Table_4_3.log", replace

/* Replicate IMF, WEO, Table 4.3 */

	/* Variant (1) : exact match */
	
xtgls unr ep ud bc2 bc2sq brr tw ep_ud ep_br ep_tw ud_bc2 ud_br /*
*/ ud_tw br_tw ce2-ce20 if 1960<=year & year<=1998, panels(h)

		/* Means */
		
sum unr ep ud bc2 bc2sq brr tw_cor ep_ud ep_br ep_tw ud_bc2 ud_br /*
*/ ud_tw br_tw if e(sample)==1

	/* Variant (2) : close, but not quite exact match */

xtgls unr ep ud bc2 bc2sq brr tw ep_ud ud_tw Lunr Lunr_bc2 Lunr_br /*
*/ cbi cbi_bc2 cstt2-cstt20 ce2-ce20 if 1960<=year & year<=1998, panels(h)

		/* Means */

sum unr ep ud bc2 bc2sq brr tw ep_ud ud_tw Lunr Lunr_bc2 Lunr_br /*
*/ cbi cbi_bc2 if e(sample)==1

	/* Variant (3) : close, but not quite exact match  */

xtgls unr ep ud bc2 bc2sq brr tw ep_ud ud_tw Lunr Lunr_bc2 Lunr_br /*
*/ cbi cbi_bc2 Ldprod rir tots csdcpi2-csdcpi20 /*
*/ cstt2-cstt20 ce2-ce20 if 1960<=year & year<=1998, panels(h)

		/* Means */

sum unr ep ud bc2 bc2sq brr tw ep_ud ud_tw Lunr Lunr_bc2 Lunr_br /*
*/ cbi cbi_bc2 Ldprod rir tots if e(sample)==1

		/* 25th & 75th percentiles */
		
capture program drop p27it
program define p27it
version 7.0
di
di _col(10) "Variable" _col(25) "25th" _col(40) "75th"
di
while "`1'"~="" {
qui sum `1' if e(sample)==1, d
local p25: display %12.3f r(p25)
local p75: display %12.3f r(p75)
di _col(10) "`1'" _col(25) "`p25'" _col(40) "`p75'"
mac shift
}
end

p27it unr ep ud bc2 bc2sq brr tw ep_ud ud_tw Lunr Lunr_bc2 Lunr_br /*
*/ cbi cbi_bc2 Ldprod rir tots
	
	/* Variant (4) : close, but not quite exact match 
	   this results for this variant differ qualitatively from those in the
	   other three variants; this is the variant that is used for simulations
	   in Table 4.1 and Figures 5.6 and 5.7; we should think about how to
	   rerun the simulations using Variant (3) instead */

xtgls unr ep ud bc2 bc2sq brr tw ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots d90s csdcpi2-csdcpi20 /*
*/ cstt2-cstt20 ce2-ce20 if 1960<=year & year<=1998, panels(h)

		/* Means */

sum unr ep ud bc2 bc2sq brr tw ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots d90s if e(sample)==1

log close

*/

/* Tables and figures for post-NYC outline */

	/* Figure 1: Dispersion of unemployment across countries, over time 
	(use Figure 1 from Howell's intro to OUP volume) */
	
	/* Table 1: Dispersion of institutions across countries, 1995-1998 */

log using "$mydoc$out\imf_lmi_Table_1.log", replace

	/* labor-force weighted, 1998 */

sum unr ep ud ud_alt bc2 bc2sq brr_alt bd_alt tw_cor tw_alt1 almpu cbi /*
*/ [w=lf_wgt] if year==1998 & cty=="USA"

sum unr ep ud ud_alt bc2 bc2sq brr_alt bd_alt tw_cor tw_alt1 almpu cbi /*
*/ [w=lf_wgt] if year==1998 & cty=="GER"

sum unr ep ud ud_alt bc2 bc2sq brr_alt bd_alt tw_cor tw_alt1 almpu cbi /*
*/ [w=lf_wgt] if year==1998 & cty=="FRA"

sum unr ep ud ud_alt bc2 bc2sq brr_alt bd_alt tw_cor tw_alt1 almpu cbi /*
*/ [w=lf_wgt] if year==1998 & cty=="ITA"

sum unr ep ud ud_alt bc2 bc2sq brr_alt bd_alt tw_cor tw_alt1 almpu cbi /*
*/ [w=lf_wgt] if year==1998 & cty=="SPA"

sum unr ep ud ud_alt bc2 bc2sq brr_alt bd_alt tw_cor tw_alt1 almpu cbi /*
*/ [w=lf_wgt] if year==1998 & cty=="NEL"

sum unr ep ud ud_alt bc2 bc2sq brr_alt bd_alt tw_cor tw_alt1 almpu cbi /*
*/ [w=lf_wgt] if year==1998 & euro4==1

sum unr ep ud ud_alt bc2 bc2sq brr_alt bd_alt tw_cor tw_alt1 almpu cbi /*
*/ [w=lf_wgt] if year==1998 & euroarea==1

sum unr ep ud ud_alt bc2 bc2sq brr_alt bd_alt tw_cor tw_alt1 almpu cbi /*
*/ [w=lf_wgt] if year==1998 & eurooecd==1

log close

/*

log using "$mydoc$out\imf_lmi_Table_2.log", replace

	/* Table 2: Testing robustness of institutional explanation (1)
	   	    Basic
	*/

		/* Col 1: IMF Table 4.3, Variant (1) */
		
			/* corrected tax wedge */
			
xtgls unr ep ud bc2 bc2sq brr tw_cor ep_ud ep_br ep_tw ud_bc2 ud_br /*
*/ ud_tw br_tw ce2-ce20 if 1960<=year & year<=1998, panels(h)

outreg ep ud bc2 bc2sq brr tw_cor ep_ud ep_br ep_tw ud_bc2 ud_br /*
*/ ud_tw br_tw /*
*/ using "$temp\table2.out", /*
*/ replace coefast bdec(3) se 10pct sigsymb(**,*,#) nocons nolabel

		/* Col 2: IMF Table 4.3, Variant (3) */

			/* corrected tax wedge; cbi */
			
xtgls unr ep ud bc2 bc2sq brr tw_cor ep_ud ud_tw Lunr Lunr_bc2 Lunr_br /*
*/ cbi cbi_bc2 Ldprod rir tots csdcpi2-csdcpi20 /*
*/ cstt2-cstt20 ce2-ce20 if 1960<=year & year<=1998, panels(h)

outreg ep ud bc2 bc2sq brr tw_cor ep_ud ud_tw Lunr Lunr_bc2 Lunr_br /*
*/ cbi cbi_bc2 Ldprod rir tots /*
*/ using "$temp\table2.out", /*
*/ append coefast bdec(3) se 10pct sigsymb(**,*,#) nocons nolabel

			/* corrected tax wedge; esi for cbi */
			
xtgls unr ep ud bc2 bc2sq brr tw_cor ep_ud ud_tw Lunr Lunr_bc2 Lunr_br /*
*/ esi esi_bc2 Ldprod rir tots csdcpi2-csdcpi20 /*
*/ cstt2-cstt20 ce2-ce20 if 1960<=year & year<=1998, panels(h)

		/* Col 3: IMF Table 4.3, Variant (4) */
		
			/* corrected tax wedge; cbi */
		
xtgls unr ep ud bc2 bc2sq brr tw_cor ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots d90s csdcpi2-csdcpi20 /*
*/ cstt2-cstt20 ce2-ce20 if 1960<=year & year<=1998, panels(h)

outreg ep ud bc2 bc2sq brr tw_cor ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots /*
*/ using "$temp\table2.out", /*
*/ append coefast bdec(3) se 10pct sigsymb(**,*,#) nocons nolabel

			/* corrected tax wedge; esi for cbi */

xtgls unr ep ud bc2 bc2sq brr tw_cor ep_ud ud_tw Lunr /*
*/ esi esi_bc2 Ldprod rir Ltots d90s csdcpi2-csdcpi20 /*
*/ cstt2-cstt20 ce2-ce20 if 1960<=year & year<=1998, panels(h)

		/* Col 4: "Our preferred" regression 
		          preferred institutions: brr_alt, bd_alt, tw_alt1
		          preferred interactions: bra_bda, ud_bc2, twa1_bc2
		          time dummies
		*/

xtgls unr ep ud_alt bc2 bc2sq brr_alt bd_alt tw_alt1 bra_bda ud_bc2 twa1_bc2 /*
*/ Lunr Ldprod rir Ltots /*
*/ ce2-ce20 td2-td39 if 1960<=year & year<=1998, panels(h)

outreg ep ud_alt bc2 bc2sq brr_alt bd_alt tw_alt1 bra_bda ud_bc2 twa1_bc2 /*
*/ Lunr Ldprod rir Ltots /*
*/ using "$temp\table2.out", /*
*/ append coefast bdec(3) se 10pct sigsymb(**,*,#) nocons nolabel

		/* "our preferred" excluding benefit duration */

xtgls unr ep ud_alt bc2 bc2sq brr_alt tw_alt1 ud_bc2 twa1_bc2 /*
*/ Lunr Ldprod rir Ltots /*
*/ ce2-ce20 td2-td39 if 1960<=year & year<=1998, panels(h)
		
		/* Col 5: Variant (3): first differences */

/* call first differencing program from prepare_imf_lmi_3.do */			
fd1 unr ep ud bc2 bc2sq brr tw_cor ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots

xtgls Dunr Dep Dud Dbc2 Dbc2sq Dbrr Dtw_cor Dep_ud Dud_tw DLunr /*
*/ Dcbi Dcbi_bc2 DLdprod Drir DLtots d90s csdcpi2-csdcpi20 /*
*/ cstt2-cstt20 ce2-ce20 if 1960<=year & year<=1998, panels(h)

outreg Dep Dud Dbc2 Dbc2sq Dbrr Dtw_cor Dep_ud Dud_tw DLunr /*
*/ Dcbi Dcbi_bc2 DLdprod Drir DLtots /*
*/ using "$temp\table2.out", /*
*/ append coefast bdec(3) se 10pct sigsymb(**,*,#) nocons nolabel
	
		/* Col 6: Variant (3): employment */

xtgls epop ep ud bc2 bc2sq brr tw_cor ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots d90s csdcpi2-csdcpi20 /*
*/ cstt2-cstt20 ce2-ce20 if 1960<=year & year<=1998, panels(h)

outreg ep ud bc2 bc2sq brr tw_cor ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots /*
*/ using "$temp\table2.out", /*
*/ append coefast bdec(3) se 10pct sigsymb(**,*,#) nocons nolabel

xtgls epop ep ud bc2 bc2sq brr tw ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots d90s csdcpi2-csdcpi20 /*
*/ cstt2-cstt20 ce2-ce20 if 1960<=year & year<=1998, panels(h)

log close

log using "$mydoc$out\imf_lmi_Table_2a.log", replace

	/* Table 2A: Variations on variant 4 */
	
		/* Col 1: IMF Variant (4) */

xtgls unr ep ud bc2 bc2sq brr tw_cor ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots d90s csdcpi2-csdcpi20 /*	
*/ cstt2-cstt20 ce2-ce20 if 1960<=year & year<=1998, panels(h)

outreg ep ud bc2 bc2sq brr tw_cor ep_ud ud_tw /*
*/ cbi cbi_bc2 Lunr /*
*/ using "$temp\table2a.out", /*
*/ replace coefast bdec(3) se 10pct sigsymb(**,*,#) nocons nolabel

		/* Col 2: IMF Variant (4), including ud_bc2  */

xtgls unr ep ud bc2 bc2sq brr tw_cor ep_ud ud_bc2 ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots d90s csdcpi2-csdcpi20 /*
*/ cstt2-cstt20 ce2-ce20 if 1960<=year & year<=1998, panels(h)

outreg ep ud bc2 bc2sq brr tw_cor ep_ud ud_bc2 ud_tw /*
*/ cbi cbi_bc2 Lunr /*
*/ using "$temp\table2a.out", /*
*/ append coefast bdec(3) se 10pct sigsymb(**,*,#) nocons nolabel

		/* Col 2: IMF Variant (4), including ud_bc2, dropping cbi  */

xtgls unr ep ud bc2 bc2sq brr tw_cor ep_ud ud_bc2 ud_tw Lunr /*
*/ Ldprod rir Ltots d90s csdcpi2-csdcpi20 /*
*/ cstt2-cstt20 ce2-ce20 if 1960<=year & year<=1998, panels(h)

outreg ep ud bc2 bc2sq brr tw_cor ep_ud ud_bc2 ud_tw /*
*/ Lunr /*
*/ using "$temp\table2a.out", /*
*/ append coefast bdec(3) se 10pct sigsymb(**,*,#) nocons nolabel

log close

log using "$mydoc$out\imf_lmi_Table_3.log", replace

	/* Testing robustness of institutional explanation (2) 
	   Adding ALMP 
	*/

		/* Col 1: Variant (3), 1985-98 only */

xtgls unr ep ud bc2 bc2sq brr tw_cor ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots d90s csdcpi2-csdcpi20 /*
*/ cstt2-cstt20 ce2-ce20 if 1985<=year & year<=1998, panels(h)

outreg ep ud bc2 bc2sq brr tw_cor ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots /*
*/ using "$temp\table3.out", /*
*/ replace coefast bdec(3) se 10pct sigsymb(**,*,#) nocons nolabel

		/* Col 2: Variant (3), 1985-98 only, plus bd, ALMP */

xtreg almpu ep ud bc2 bc2sq brr bd_alt almpu_iv tw_cor ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots d90s csdcpi2-csdcpi20 /*
*/ cstt2-cstt20 ce2-ce20 if 1985<=year & year<=1998
predict almphat1

xtgls unr ep ud bc2 bc2sq brr bd_alt almphat1 tw_cor ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots d90s csdcpi2-csdcpi20 /*
*/ cstt2-cstt20 ce2-ce20 if 1985<=year & year<=1998, panels(h)

outreg ep ud bc2 bc2sq brr almphat1 tw_cor ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots /*
*/ using "$temp\table3.out", /*
*/ append coefast bdec(3) se 10pct sigsymb(**,*,#) nocons nolabel

		/* Col 3: Variant (4), alternative, 1985-98 only, plus bd, ALMP */

xtreg almpu ep ud bc2 bc2sq brr bd_alt tw_cor almpu_iv /*
*/ ep_ud ud_bc2 ud_tw Lunr Ldprod rir Ltots d90s csdcpi2-csdcpi20 /*
*/ cstt2-cstt20 ce2-ce20 if 1985<=year & year<=1998
predict almphat2

xtgls unr ep ud bc2 bc2sq brr bd_alt tw_cor almphat2 /*
*/ ep_ud ud_bc2 ud_tw Lunr Ldprod rir Ltots d90s csdcpi2-csdcpi20 /*
*/ cstt2-cstt20 ce2-ce20 if 1985<=year & year<=1998, panels(h)

outreg ep ud bc2 bc2sq brr bd_alt tw_cor almphat2 ep_ud ud_bc2 ud_tw /*
*/ Lunr /*
*/ using "$temp\table3.out", /*
*/ append coefast bdec(3) se 10pct sigsymb(**,*,#) nocons nolabel

		/* Col 4: Variant (4), alternative, 1985-98 only, no bd, no ALMP */

xtgls unr ep ud bc2 bc2sq brr tw_cor /*
*/ ep_ud ud_bc2 ud_tw Lunr Ldprod rir Ltots d90s csdcpi2-csdcpi20 /*
*/ cstt2-cstt20 ce2-ce20 if 1985<=year & year<=1998, panels(h)

outreg ep ud bc2 bc2sq brr tw_cor ep_ud ud_bc2 ud_tw /*
*/ Lunr /*
*/ using "$temp\table3.out", /*
*/ append coefast bdec(3) se 10pct sigsymb(**,*,#) nocons nolabel

		
		/* Col 5: "Our preferred", 1985-99 only, including bd, ALMP,
		           no cbi cbi_bc2 terms  
		*/

xtreg almpu ep ud bc2 bc2sq brr bd_alt tw_cor almpu_iv /*
*/ ep_ud ud_bc2 ud_tw Lunr Ldprod rir Ltots d90s csdcpi2-csdcpi20 /*
*/ cstt2-cstt20 ce2-ce20 if 1985<=year & year<=1998
predict almphat3

xtgls unr ep ud_alt bc2 bc2sq brr_alt bd_alt tw_alt1 almphat3 /*
*/ bra_bda ud_bc2 twa1_bc2 Lunr Ldprod rir Ltots /*
*/ ce2-ce20 td2-td39 if 1985<=year & year<=1998, panels(h)

outreg ep ud_alt bc2 bc2sq brr_alt bd_alt tw_alt1 almphat3 /*
*/ bra_bda ud_bc2 twa1_bc2 Ldprod rir Ltots /*
*/ using "$temp\table3.out", /*
*/ append coefast bdec(3) se 10pct sigsymb(**,*,#) nocons nolabel

log close

*/

log using "$mydoc$out\imf_lmi_Table_4.log", replace

	/* Table 4: Testing robustness of institutional explanation (3) 
		    Cross-country explanatory power
	*/

/* create averages for 1990-94, 1995-98 */
preserve
gen byte period=1 if 1990<=year & year<=1994
replace period=2 if  1995<=year & year<=1998

collapse unr ep ud ud_alt bc2 brr brr_alt bd bd_alt tw_cor /*
*/ tw_alt1 tw_alt2 almpu_iv dcpi, by(country period)

/* create period dummies */
tab period, gen(perdum)

/* add union coverage index using information from 
Blanchard and Wolfers (2000) and Nickell (1997);
from Nickell: "...3 means over 79 percent covered, 2 means
from 25-70 percent, and 1 is under 25 percent." (p. 62);
Nickell, Table 5 provides 1989-94 figures; Blanchard and Wolfers 
data set provides averages for 1983-88 and 1989-94 periods, which 
allows 1983-88 figures to be deduced */
gen byte ucov=3
/* since union coverage is 3 for most countries, and union
coverage shows no movement across periods (except apparently in
the United Kingdom */
replace ucov=2 if country=="Canada"| country=="Japan" | country=="New Zealand"
replace ucov=1 if country=="United States"
replace ucov=2 if country=="United Kingdom" /* Nickell */
/* B&W list average for UK entire 1983-94 period as 2.5 */

encode country, gen(cty)
/* set time series variables */
tsset cty period, yearly
iis cty
tis period

/* (1a): approximating Nickell 1997 using IMF 2003 data : 1990-98 */

xtgls unr ep ud bc2 brr tw_cor /*
*/ dcpi perdum2 if period==1 | period==2, panels(h)

xtgls unr ep ud bc2 brr tw_cor /*
*/ dcpi perdum2 if period==1 | period==2

xtreg unr ep ud bc2 brr tw_cor /*
*/ dcpi perdum2 if period==1 | period==2, re

outreg ep ud bc2 brr tw_cor dcpi perdum2 /*
*/ using "$temp\table4.out", /*
*/ replace coefast bdec(3) se 10pct sigsymb(**,*,#) nocons nolabel

/* (1b): approximating Nickell 1997 using IMF 2003 data, plus data from
other sources for ALMP and union coverage, which are not in the IMF 2003 data:
1985-94. 

Union coverage is a time invariant index (1, low; 2, medium; 3, high)
from Blanchard and Wolfers 1999. The Belot and Van Ours data set has a time-varying
variable, but it shows very little variation (even less over just the 1985-94
period) and is missing data for Spain and Portugal. The ALMP data are instrumented
(see this program, above) and based on OECD data.
*/

xtgls unr ep ud_alt bc2 brr_alt bd_alt tw_alt1 ucov almpu_iv /*
*/ dcpi perdum2 if period==1 | period==2, panels(h)

xtgls unr ep ud_alt bc2 brr_alt bd_alt tw_alt1 ucov almpu_iv /*
*/ dcpi perdum2 if period==1 | period==2

xtreg unr ep ud_alt bc2 brr_alt bd_alt tw_alt1 ucov almpu_iv /*
*/ dcpi perdum2 if period==1 | period==2, re

xtreg unr ep ud bc2 brr bd_alt tw_cor ucov almpu_iv /*
*/ dcpi perdum2 if period==1 | period==2, re

outreg ep ud bc2 brr bd_alt tw_cor ucov almpu_iv dcpi perdum2 /*
*/ using "$temp\table4.out", /*
*/ append coefast bdec(3) se 10pct sigsymb(**,*,#) nocons nolabel

restore
log close

	/* Table 5: Predicted effects of policy changes in OECD Europe 
		    set Europe equal to US level
		    set Europe equal to Dutch level
	*/
	
	/* Table 6: "Cross-country evidence from OECD's evaluation of reform
	            efforts [see Table 3.7 from Chapter 3]
	*/

log using "$mydoc$out\imf_lmi_response_table_4.log", replace

	/* IMF response table */
	
		/* variant 2: exact match to 3-4 decimals; 
		   except (1) standard errors; (2) fixed effects */

xtgls unr ep ud bc2 bc2sq brr tw ep_ud ud_tw Lunr Lunr_bc2 Lunr_br /*
*/ cbi cbi_bc2 cstt1-cstt20 ce1-ce20 if 1960<=year & year<=1998, /*
*/ panels(h) nocons

		/* variant 3: exact match to 3-4 decimals;
		   except (1) standard errors; (2) fixed effects */
		   
xtgls unr ep ud bc2 bc2sq brr tw ep_ud ud_tw Lunr Lunr_bc2 Lunr_br /*
*/ cbi cbi_bc2 Ldprod rir tots csdcpi1-csdcpi20 /*
*/ cstt1-cstt20 ce1-ce20 if 1960<=year & year<=1998, panels(h)

/* create German unification and Finland dummies */
gen byte unif=0
replace unif=1 if euroarea==1 & (year==1990 | year==1991)
gen byte ussr=0
replace ussr=1 if cty=="FIN" & (year==1991 | year==1992)

		/* variant 4: near, but not identical */

xtgls unr ep ud bc2 bc2sq brr tw ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots unif ussr csdcpi1-csdcpi20 /*
*/ cstt1-cstt20 ce1-ce20 if 1960<=year & year<=1998, nocons panels(h)

		/* no time trend; country-specific CPI 
		   no tax wedge */

xtgls unr ep ud bc2 bc2sq brr ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots d90s csdcpi1-csdcpi20 /*
*/ ce1-ce20 if 1960<=year & year<=1998, panels(h) nocons


		/* no time trend; country-specific CPI;
		   tax wedge */
		   
xtgls unr ep ud bc2 bc2sq brr tw_cor ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots d90s csdcpi1-csdcpi20 /*
*/ ce1-ce20 if 1960<=year & year<=1998, panels(h) nocons

		/* no time trend; common CPI term;
		   no tax wedge */

xtgls unr ep ud bc2 bc2sq brr ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots d90s dcpi /*
*/ ce1-ce20 if 1960<=year & year<=1998, panels(h) nocons

		/* no time trend; common CPI term;
		   tax wedge */

xtgls unr ep ud bc2 bc2sq brr tw_cor ep_ud ud_tw Lunr /*
*/ cbi cbi_bc2 Ldprod rir Ltots d90s dcpi /*
*/ ce1-ce20 if 1960<=year & year<=1998, panels(h) nocons

log close

*/
  
	/* Figure 1 */

preserve
gen byte period=1 if 1960<=year & year<=1964
replace period=2 if  1965<=year & year<=1969
replace period=3 if  1970<=year & year<=1974
replace period=4 if  1975<=year & year<=1979
replace period=5 if  1980<=year & year<=1984
replace period=6 if  1985<=year & year<=1989
replace period=7 if  1990<=year & year<=1994
replace period=8 if  1995<=year & year<=1999
replace period=9 if  2000<=year & year<=2002

collapse unr, by(cty period)
rename unr sur
sort cty period
save "$mydoc$data\fig1.dta", replace

/* add data for 2001 and 2002 */
clear
set obs 40
* year
gen int year=2001 in 1/20
replace year=2002 in 21/40
* country  
gen str3 cty="AUS" in 1
replace cty="AUT" in 2
replace cty="BEL" in 3
replace cty="CAN" in 4
replace cty="DEN" in 5
replace cty="FIN" in 6
replace cty="FRA" in 7
replace cty="GER" in 8
replace cty="IRE" in 9
replace cty="ITA" in 10
replace cty="JAP" in 11
replace cty="NEL" in 12
replace cty="NEW" in 13
replace cty="NOR" in 14
replace cty="POR" in 15
replace cty="SPA" in 16
replace cty="SWE" in 17
replace cty="SWZ" in 18
replace cty="UK_" in 19
replace cty="USA" in 20
replace cty="AUS" in 21
replace cty="AUT" in 22
replace cty="BEL" in 23
replace cty="CAN" in 24
replace cty="DEN" in 25
replace cty="FIN" in 26
replace cty="FRA" in 27
replace cty="GER" in 28
replace cty="IRE" in 29
replace cty="ITA" in 30
replace cty="JAP" in 31
replace cty="NEL" in 32
replace cty="NEW" in 33
replace cty="NOR" in 34
replace cty="POR" in 35
replace cty="SPA" in 36
replace cty="SWE" in 37
replace cty="SWZ" in 38
replace cty="UK_" in 39
replace cty="USA" in 40
* standardized unemployment rates, October 2003, http://www.oecdwash.org
gen sur=6.7 if cty=="AUS" & year==2001
replace sur=3.6 if cty=="AUT" & year==2001
replace sur=6.7 if cty=="BEL" & year==2001
replace sur=7.2 if cty=="CAN" & year==2001
replace sur=4.3 if cty=="DEN" & year==2001
replace sur=9.1 if cty=="FIN" & year==2001
replace sur=8.5 if cty=="FRA" & year==2001
replace sur=7.8 if cty=="GER" & year==2001
replace sur=3.9 if cty=="IRE" & year==2001
replace sur=9.4 if cty=="ITA" & year==2001
replace sur=5.0 if cty=="JAP" & year==2001
replace sur=2.4 if cty=="NEL" & year==2001
replace sur=5.3 if cty=="NEW" & year==2001
replace sur=3.6 if cty=="NOR" & year==2001
replace sur=4.1 if cty=="POR" & year==2001
replace sur=10.6 if cty=="SPA" & year==2001
replace sur=4.9 if cty=="SWE" & year==2001
replace sur=2.6 if cty=="SWZ" & year==2001
replace sur=5.0 if cty=="UK_" & year==2001
replace sur=4.7 if cty=="USA" & year==2001
replace sur=6.3 if cty=="AUS" & year==2002
replace sur=4.3 if cty=="AUT" & year==2002
replace sur=7.3 if cty=="BEL" & year==2002
replace sur=7.7 if cty=="CAN" & year==2002
replace sur=4.5 if cty=="DEN" & year==2002
replace sur=9.1 if cty=="FIN" & year==2002
replace sur=8.8 if cty=="FRA" & year==2002
replace sur=8.6 if cty=="GER" & year==2002
replace sur=4.4 if cty=="IRE" & year==2002
replace sur=9.0 if cty=="ITA" & year==2002
replace sur=5.4 if cty=="JAP" & year==2002
replace sur=2.8 if cty=="NEL" & year==2002
replace sur=5.2 if cty=="NEW" & year==2002
replace sur=3.9 if cty=="NOR" & year==2002
replace sur=5.1 if cty=="POR" & year==2002
replace sur=11.3 if cty=="SPA" & year==2002
replace sur=4.9 if cty=="SWE" & year==2002
replace sur=3.1 if cty=="SWZ" & year==2002
replace sur=5.1 if cty=="UK_" & year==2002
replace sur=5.8 if cty=="USA" & year==2002
* append 1960-2000 data
append using "$mydoc$data\fig1.dta"
replace period=9 if 2000<=year & year==2002
* label data
#delimit ;
lab def period
1 "1960-64"
2 "65-69"
3 "70-74"
4 "75-79"
5 "80-84"
6 "85-89"
7 "90-94"
8 "95-99"
9 "2000-02"
;
#delimit cr
lab val period period
save "$mydoc$data\fig1.dta", replace

set textsize 110

gr sur period, c(.) s(O) psize(200) /*
*/ xlab(1,2,3,4,5,6,7,8,9) ylab(0,5,10,15,20) /*
*/ t1("Standardized unemployment rate, OECD, 1960-2002") /*
*/ l1("Unemployment rate, %") b2(" ") /*
*/ saving("$mydoc$out\fig1o",replace)

restore

	/* Figures 2-8: Bivariate unemployment-institution graphs
	   Figure 2: Benefit replacement ratio
	   Figure 3: Benefit duration
	   Figure 4: Tax wedge (corrected)
	   Figure 5: Employment protection
	   Figure 6: Union density
	   Figure 7: Bargaining coordination
	   Figure 8: Active labor market policies
	*/

preserve
gen byte period=1 if 1980<=year & year<=1984
replace period=2 if  1985<=year & year<=1989
replace period=3 if  1990<=year & year<=1994
replace period=4 if  1995<=year & year<=1998

collapse unr ep ud ud_alt bc2 brr brr_alt bd bd_alt tw_cor /*
*/ tw_alt1 tw_alt2 almpu almpu_iv, by(cty period)

drop if period==.

set textsize 120

	/* Figure 2 */
	
reg unr ep if period~=.
local t_ep : display %5.2f _b[ep]/_se[ep]
predict f2_unr if period~=.

gr unr f2_unr ep if period~=., c(.l) s(O.) ylab(0,5,10,15,20) xlab /*
*/ t1("Employment protection and unemployment, OECD, 1980-98") /*
*/ t2("t-statistic of fitted line = `t_ep'") /*
*/ l2("Unemployment rate, %") b2("Employment protection index") /*
*/ saving("$mydoc$out\fig2o",replace)


	/* Figure 3 */
	
format ud_alt %5.1f 
reg unr ud_alt if period~=.
local t_uda : display %5.2f _b[ud_alt]/_se[ud_alt]
predict f3_unr if period~=.

gr unr f3_unr ud_alt if period~=., c(.l) s(O.) ylab(0,5,10,15,20) xlab /*
*/ t1("Union density and unemployment, OECD, 1980-98") /*
*/ t2("t-statistic of fitted line = `t_uda'") /*
*/ l2("Unemployment rate, %") b2("Union density, %") /*
*/ saving("$mydoc$out\fig3o",replace)

	/* Figure 4 */
	
reg unr bc2 if period~=.
local t_bc2 : display %5.2f _b[bc2]/_se[bc2]
predict f4_unr if period~=.

gr unr f4_unr bc2 if period~=., c(.l) s(O.) ylab(0,5,10,15,20) xlab /*
*/ t1("Bargaining coordination and unemployment, OECD, 1980-98") /*
*/ t2("t-statistic of fitted line = `t_bc2'") /*
*/ l2("Unemployment rate, %") b2("Bargaining coordination index") /*
*/ saving("$mydoc$out\fig4o",replace)

	/* Figure 5 */

format brr_alt %5.1f
	
reg unr brr_alt if period~=.
local t_bra : display %5.2f _b[brr_alt]/_se[brr_alt]
predict f5_unr if period~=.

gr unr f5_unr brr_alt if period~=., c(.l) s(O.) ylab(0,5,10,15,20) xlab /*
*/ t1("Benefit replacement rate and unemployment, OECD, 1980-98") /*
*/ t2("t-statistic of fitted line = `t_bra'") /*
*/ l2("Unemployment rate, %") b2("Benefit replacement rate, %") /*
*/ saving("$mydoc$out\fig5o",replace)

	/* Figure 6 */
	
reg unr bd_alt if period~=.
local t_bda : display %5.2f _b[bd_alt]/_se[bd_alt]
predict f6_unr if period~=.

gr unr f6_unr bd_alt if period~=., c(.l) s(O.) ylab(0,5,10,15,20) xlab /*
*/ t1("Benefit duration and unemployment, OECD, 1980-98") /*
*/ t2("t-statistic of fitted line = `t_bda'") /*
*/ l2("Unemployment rate, %") b2("Benefit duration index") /*
*/ saving("$mydoc$out\fig6o",replace)

	/* Figure 7 */

format tw_alt1 %5.1f

reg unr tw_alt1 if period~=.
local t_twa1 : display %5.2f _b[tw_alt1]/_se[tw_alt1]
predict f7_unr if period~=.

gr unr f7_unr tw_alt1 if period~=., c(.l) s(O.) ylab(0,5,10,15,20) xlab /*
*/ t1("Tax wedge and unemployment, OECD, 1980-98") /*
*/ t2("t-statistic of fitted line = `t_twa1'") /*
*/ l2("Unemployment rate, %") b2("Tax wedge, %") /*
*/ saving("$mydoc$out\fig7o",replace)

	/* Figure 8 */
	
reg unr almpu if period~=.
local t_almp : display %5.2f _b[almpu]/_se[almpu]
predict f8_unr if period~=.

gr unr f8_unr almpu if period~=., c(.l) s(O.) ylab(0,5,10,15,20) xlab /*
*/ t1("ALMPs and unemployment, OECD, 1980-98") /*
*/ t2("t-statistic of fitted line = `t_almp'") /*
*/ l2("Unemployment rate, %") b2("ALMP, GDP[%] / Unemployment[%]") /*
*/ saving("$mydoc$out\fig8o",replace)

reg unr almpu if cty~="SWE" & period~=.
local t_almp9 : display %5.2f _b[almpu]/_se[almpu]
predict f9_unr if cty~="SWE" & period~=.

gr unr f9_unr almpu if cty~="SWE" & period~=., c(.l) s(O.) ylab(0,5,10,15,20) xlab /*
*/ t1("ALMPs (excluding SWEDEN) and unemployment, OECD, 1980-98") /*
*/ t2("t-statistic of fitted line = `t_almp9'") /*
*/ l2("Unemployment rate, %") b2("ALMP, GDP[%] / Unemployment[%]") /*
*/ saving("$mydoc$out\fig9o",replace)

restore

