set more 1
capture log close

/*
File:	prepare_imf_lmi_4.do
Date:	Sep 11, 2003; Nov 18, 2003
Desc:	Prepars base data used for IMF, World Economic Outlook, April 2003,
	Chapter IV: "Unemployment and Labor Market Institutions:
	Why Reforms Pay Off" for regression and other analysis
*/

/* set directories
see master_imf_lmi.do
*/

use "$mydoc$data\imf_lmi.dta", clear

/* reformat for easy comparability with IMF WEO Chapter */
replace ud=ud*100
replace ud_alt=ud_alt*100
replace brr=brr*100
replace brr_alt=brr_alt*100
replace tw=tw*100
replace tw_cor=tw_cor*100
replace tw_alt1=tw_alt1*100
replace tw_alt2=tw_alt2*100
replace rir=rir*100
replace tots=tots*100

/* fixed effects */
tab country, gen(ce)
tab year, gen(ye)

/* convert country to numeric for use as Stata iis indicator variable */
encode country, gen(cntry)

/* quadratic bargaining coordination */
gen bc1sq=bc1*bc1
gen bc2sq=bc2*bc2

/* labor-market institution interactions */
	* IMF interactions
gen ep_ud=ep*ud
gen ep_uda=ep*ud_alt
gen ep_br=ep*brr
gen ep_bra=ep*brr_alt
gen ep_tw=ep*tw
gen ep_twc=ep*tw_cor
gen ep_twa1=ep*tw_alt1
gen ep_twa2=ep*tw_alt2
gen ud_bc1=ud*bc1
gen ud_bc2=ud*bc2
gen ud_br=ud*brr
gen ud_bra=ud*brr_alt
gen ud_tw=ud*tw
gen ud_twc=ud*tw_cor
gen ud_twa1=ud*tw_alt1
gen ud_twa2=ud*tw_alt2
gen uda_bc1=ud_alt*bc1
gen uda_bc2=ud_alt*bc2
gen uda_br=ud_alt*brr
gen uda_bra=ud_alt*brr_alt
gen uda_tw=ud_alt*tw
gen uda_twc=ud_alt*tw_cor
gen uda_twa1=ud_alt*tw_alt1
gen uda_twa2=ud_alt*tw_alt2
gen br_tw=brr*tw
gen br_twc=brr*tw_cor
gen br_twa1=brr*tw_alt1
gen br_twa2=brr*tw_alt2
gen bra_tw=brr_alt*tw
gen bra_twc=brr_alt*tw_cor
gen bra_twa1=brr_alt*tw_alt1
gen bra_twa2=brr_alt*tw_alt2
	* Other interactions
gen br_bd=brr*bd
gen bra_bd=brr_alt*bd
gen br_bda=brr*bd_alt
gen bra_bda=brr_alt*bd_alt
gen twc_bc1=tw_cor*bc1
gen twc_bc2=tw_cor*bc2
gen twa1_bc1=tw_alt1*bc1
gen twa1_bc2=tw_alt1*bc2
gen twa2_bc1=tw_alt2*bc1
gen twa2_bc2=tw_alt2*bc2

/* lagged unemployment rate and interactions */
sort country year
by country: gen Lunr=unr[_n-1]
gen Lunr_bc1=Lunr*bc1
gen Lunr_bc2=Lunr*bc2
gen Lunr_br =Lunr*brr
gen Lunr_bra=Lunr*brr_alt

/* macroeconomic institution interactions */
gen cbi_bc1=cbi*bc1
gen cbi_bc2=cbi*bc2
gen esi_bc1=esi*bc1
gen esi_bc2=esi*bc2

/* productivity growth rate */
sort country year
by country: gen dprod=100*(prod1[_n]-prod1[_n-1])/prod1[_n-1]

/* lagged macroeconomic variables */
sort country year
by country: gen Ldprod=dprod[_n-1]
sort country year
by country: gen Ltots=tots[_n-1]

/* prepare ALMP variable for analysis */

	/* divide ALMP spending by share of unemployed */
gen almpu=almp/unr
label var almpu "ALMP/Unemployment"
	/* following Nickell 1997, create instrument for ALMP by 
	   dividing ALMP spending by mean unemployment rate, 1977-79 */
sort country year
by country: gen u7779=(unr[18]+unr[19]+unr[20])/3
gen almpu_iv=almp/u7779
label var almpu_iv "ALMP/Unemployment, instrument"

/* effect of German unification on euro area; impact of end
   of Soviet Union on Finland */
gen byte d90s=0
replace d90s=1 if (year==1990 | year==1991) & /*
*/ (cty=="AUT" | cty=="BEL" | cty=="FRA" | cty=="GER" | cty=="IRE" | /*
*/  cty=="ITA" | cty=="NEL" | cty=="NOR" | cty=="POR" | cty=="SPA" | /*
*/  cty=="SWE")
replace d90s=1 if (year==1991 | year==1992) & cty=="FIN"
lab var d90s "Euro area + Finland, Early 1990s"

/* time trends */

	/* general */

sort country year
by country: gen byte tt=[_n]

	/* country-specific time trend */

capture program drop cstt
program define cstt
version 7.0
local i=1
while `i'<=20 {
gen byte cstt`i'=0
replace cstt`i'=[_n] if cty=="`1'"
local i=`i'+1
mac shift
}
end

cstt AUS AUT BEL CAN DEN FIN FRA GER IRE ITA JAP NEL NEW NOR POR SPA SWE /*
*/ SWZ UK_ USA

/* country-specific change-in-inflation term */

	/* dcpi */
sort country year
by country: gen dcpi=infl[_n]-infl[_n-1]

capture program drop csdcpi
program define csdcpi
version 7.0
local i=1
while `i'<=20 {
gen byte csdcpi`i'=0
replace csdcpi`i'=dcpi[_n] if cty=="`1'"
local i=`i'+1
mac shift
}
end

csdcpi AUS AUT BEL CAN DEN FIN FRA GER IRE ITA JAP NEL NEW NOR POR SPA SWE /*
*/ SWZ UK_ USA

/* time dummies */

tab year, gen(td)

/* first differences */

capture program drop fd1
program define fd1
version 7.0
while "`1'"~="" {
sort country year
by country: gen D`1'=`1'[_n]-`1'[_n-1]
mac shift
}
end

/* number countries */
encode cty, gen(ctyn)

/* country groupings */

	* Continental 4
	
gen byte euro4=0 if cty~=""
replace euro4=1 if cty=="FRA" | cty=="GER" | cty=="ITA" | cty=="SPA"

	* Euro area
	
gen byte euroarea=0 if cty~=""
replace euroarea=1 if cty=="AUT" | cty=="BEL" | cty=="FIN" | cty=="FRA" | /*
*/ cty=="GER" | cty=="IRE" | cty=="ITA" | cty=="NEL" | cty=="POR" | cty=="SPA"

	* OECD Europe
	
gen byte eurooecd=0 if cty~=""
replace eurooecd=1 if cty=="AUT" | cty=="BEL" | cty=="DEN" | cty=="FIN" | /*
*/ cty=="FRA" | cty=="GER" | cty=="IRE" | cty=="ITA" | cty=="NEL" | /*
*/ cty=="NOR" | cty=="POR" | cty=="SPA" | cty=="SWE" | cty=="SWZ" | cty=="UK_"

drop if cntry==.

/* Labor force weighting variable
   IMF uses labor force (in unspecified years) to weight institutional
   characteristics across groups of countries; the IMF's original data
   base does not include the labor-force variable used in their weighting;
   the OECD labor-force variable added earlier to the IMF data set has
   missing values for some countries in some years; for purposes of weighting
   only, the following fills in missing values for the labor force in each
   country by using the labor force from the closest available year; this
   prevents observations used in any regression from being excluded because
   of a corresponding missing labor-variable value
*/
gen lf_wgt=lf_all
replace lf_wgt=4593 if cty=="AUS" & (1960<=year & year<=1963)
replace lf_wgt=3119 if cty=="AUT" & (1960<=year & year<=1967)
replace lf_wgt=4375 if cty=="BEL" & year==2000
replace lf_wgt=2094 if cty=="DEN" & (1961<=year & year<=1962)
replace lf_wgt=2252 if cty=="DEN" & (1963<=year & year<=1966)
replace lf_wgt=2340 if cty=="DEN" & year==1968
replace lf_wgt=5003 if cty=="NEL" & (1960<=year & year<=1974)
replace lf_wgt=4159 if cty=="SWE" & (1960<=year & year<=1975)

compress
save "$mydoc$data\imf_lmi_ready_ver6.dta", replace old
save "$mydoc$data\imf_lmi_ready.dta", replace

